@@ -60,7 +60,7 @@ def can_load_page(func):
             expect_loading = kwargs['expect_loading']
             del kwargs['expect_loading']
         if expect_loading:
-            self.loaded = False
+            self._loaded = False
             func(self, *args, **kwargs)
             return self.wait_for_page_loaded()
         return func(self, *args, **kwargs)
@@ -81,9 +81,9 @@ def have_a_break(func):
             interval = kwargs['sleep']
             del kwargs['sleep']
         else:
-            sleep=self.sleep
+            sleep = self.sleep
 
-        result=func(self, *args, **kwargs)
+        result = func(self, *args, **kwargs)
         gevent.sleep(sleep)
         return result
 
@@ -132,11 +132,12 @@ class XPath(object):
 
 
 class GRobotNetworkAccessManager(QNetworkAccessManager):
-    def __init__(self, parent=None):
+    def __init__(self, robot, parent=None):
+        self._robot = robot
         super(GRobotNetworkAccessManager, self).__init__(parent)
 
     def createRequest(self, op, req, outgoingData=None):
-        req.setRawHeader('Accept-Language', 'en,*')
+        req.setRawHeader('Accept-Language', self._robot.accept_language)
         return super(GRobotNetworkAccessManager, self).createRequest(op, req, outgoingData)
 
 
@@ -149,7 +150,7 @@ class GRobotWebPage(QtWebKit.QWebPage):
     def __init__(self, robot, parent=None):
         super(GRobotWebPage, self).__init__(parent)
         self._robot = robot
-        self.setNetworkAccessManager(GRobotNetworkAccessManager(self))
+        self.setNetworkAccessManager(GRobotNetworkAccessManager(self._robot, self))
 
     def javaScriptConsoleMessage(self, message, line, source):
         """Prints client console message in current output stream."""
@@ -258,8 +259,7 @@ class QtMainLoop(object):
                 # GRobot._app.processEvents()
                 while self._app.hasPendingEvents():
                     self._app.processEvents()
-                    # gevent.sleep(0)
-                gevent.sleep(0)
+                gevent.sleep(0.01)
         except Exception, e:
             logger.error(e)
         logger.debug('Goodbye GRobot')
@@ -347,16 +347,14 @@ class prompt:
 class GRobot(object):
     _loop = None
     _liveRobot = 0
-
     _app = None
-
     exit_lock = RLock()
 
     def __init__(self, user_agent=default_user_agent, operate_timeout=10, loading_timeout=60, log_level=logging.WARNING,
                  display=False, viewport_size=(1024, 768), accept_language='en,*', ignore_ssl_errors=True,
                  cache_dir=os.path.join(tempfile.gettempdir(), "GRobot"),
                  image_enabled=True, plugins_enabled=False, java_enabled=False, javascript_enabled=True,
-                 plugin_path=None, develop=False, proxy=None,sleep=0.5):
+                 plugin_path=None, develop=False, proxy=None, sleep=0.5, jquery_namespace='GRobot'):
         """GRobot manages a QWebPage.
     
         @param user_agent: The default User-Agent header.
@@ -365,7 +363,7 @@ class GRobot(object):
         @param log_level: The optional logging level.
         @param display: A boolean that tells GRobot to displays UI.
         @param viewport_size: A tupple that sets initial viewport size.
-        @param accept_language:
+        @param accept_language: Set the webkit accept language. 
         @param ignore_ssl_errors: A boolean that forces ignore ssl errors.
         @param cache_dir: A directory path where to store cache datas.
         @param image_enabled: Enable images.
@@ -376,20 +374,29 @@ class GRobot(object):
         @param develop: Enable the Webkit Inspector.
         @param proxy: Set a Socks5,HTTP{S} Proxy
         @param sleep: Sleep `sleep` second,after operate
+        @param jquery_namespace: Set the jQuery namespace.
         """
 
         GRobot.exit_lock.acquire()
+        logger.setLevel(log_level)
+
         plugin_path = plugin_path or ['/usr/lib/mozilla/plugins', ]
 
         GRobot._liveRobot += 1
+
         self.develop = develop
         self.inspector = None
         self.plugin = False
         self.exitLoop = False
-        self.set_proxy(proxy)
-        self.sleep=sleep
 
+        self.set_proxy(proxy)
+
+        self.sleep = sleep
+        self.jquery_namespace = jquery_namespace
         self.popup_messages = None
+        self.accept_language = accept_language
+
+        self._loaded = True
 
         self._confirm_expected = None
         self._prompt_expected = None
@@ -405,8 +412,6 @@ class GRobot(object):
 
         self.ignore_ssl_errors = ignore_ssl_errors
 
-        self.loaded = True
-
         if not sys.platform.startswith('win') and not 'DISPLAY' in os.environ \
             and not hasattr(GRobot, 'xvfb'):
             try:
@@ -432,8 +437,6 @@ class GRobot(object):
 
         self.page.setForwardUnsupportedContent(True)
 
-
-
         # Page signals
         self.page.loadFinished.connect(self._page_loaded)
         self.page.loadStarted.connect(self._page_load_started)
@@ -467,8 +470,6 @@ class GRobot(object):
 
         self.main_frame = self.page.mainFrame()
 
-        logger.setLevel(log_level)
-
         self.webview = None
 
         self.viewport_size = viewport_size
@@ -580,7 +581,7 @@ class GRobot(object):
         self._auth = auth
         self._auth_attempt = 0  # Avoids reccursion
         self.page.mainFrame().load(request, method, body)
-        self.loaded = False
+        self._loaded = False
 
         if default_popup_response is not None:
             self._prompt_expected = (default_popup_response, None)
@@ -599,6 +600,7 @@ class GRobot(object):
             self.webview.resize(QSize(width, height))
         self.page.setViewportSize(QSize(width, height))
 
+
     def set_proxy(self, proxy=None):
         """Set the proxy or using system configuration as None,supported socks5 http{s}.
 
@@ -634,6 +636,11 @@ class GRobot(object):
 
 
     def elements_position(self, selector):
+        """Get the position of elements whose match selector
+
+        @param selector:
+        @return: position of QPoint
+        """
         attr, pattern, val = self.parser_selector(selector, attr='identifier')
 
         strip = lambda v: v.strip()
@@ -712,7 +719,7 @@ class GRobot(object):
         @return:
         """
 
-        self.trigger_action('Reload',expect_loading=True)
+        self.trigger_action('Reload', expect_loading=True)
 
     def back(self):
         self.trigger_action('Back')
@@ -768,8 +775,8 @@ class GRobot(object):
         return pos
 
 
-    def qpoint_to_tuple(self,qpoint):
-        return qpoint.x(),qpoint.y()
+    def qpoint_to_tuple(self, qpoint):
+        return qpoint.x(), qpoint.y()
 
     @have_a_break
     def move_to(self, selector):
@@ -793,7 +800,7 @@ class GRobot(object):
     def key_clicks(self, selector, text):
         if selector:
             self.click(selector)
-        QTest.keyClicks(self.webview, text,delay=50)
+        QTest.keyClicks(self.webview, text, delay=50)
 
     @have_a_break
     def type(self, selector, text):
@@ -807,7 +814,7 @@ class GRobot(object):
             core.events.setValue(this, '%s')
             """ % (text.replace("\n", "\\n").replace("\'", "\\'"))
         )
-        logger.debug('type %s %s'%(selector,text))
+        logger.debug('type %s %s' % (selector, text))
 
 
     def _hit_element_from(self, position):
@@ -820,7 +827,7 @@ class GRobot(object):
 
 
     def wait_forever(self):
-        self.wait_for(lambda :False,time_for_stop=-1)
+        self.wait_for(lambda: False, time_for_stop=-1)
 
     @have_a_break
     def check(self, selector, checked=True):
@@ -858,7 +865,7 @@ class GRobot(object):
             }
             """ % ( query.replace("\'", "\\'"), select_by, select_by))
 
-        def _add_selection(query, select_by, select,selected):
+        def _add_selection(query, select_by, select, selected):
             select.evaluateJavaScript(u"""
             triggerEvent(this, 'focus', false);
             var optionToSelect = '%s';
@@ -879,10 +886,10 @@ class GRobot(object):
             ele.setFocus()
 
             if ele.attribute('multiple') == 'multiple':
-                assert isinstance(value,list)
-                for value_,selected in value:
+                assert isinstance(value, list)
+                for value_, selected in value:
                     attr, pattern, val = self.parser_selector(value_, attr='text')
-                    _add_selection(val, attr, ele,selected)
+                    _add_selection(val, attr, ele, selected)
             else:
                 attr, pattern, val = self.parser_selector(value, attr='text')
                 _select(val, attr, ele)
@@ -1172,7 +1179,7 @@ class GRobot(object):
         """Waits until page is loaded, assumed that a page as been requested.
 
         """
-        return self.wait_for(lambda: self.loaded,
+        return self.wait_for(lambda: self._loaded,
                              'Unable to load requested page', time_for_stop=time_for_stop)
 
     def wait_for(self, condition, timeout_message='', time_for_stop=None):
@@ -1182,7 +1189,7 @@ class GRobot(object):
         @param timeout_message: The exception message on timeout.-1 means never timeout.
         """
 
-        if self.loaded:
+        if self._loaded:
             time_for_stop = time_for_stop or self.operate_timeout
         else:
             time_for_stop = time_for_stop or self.loading_timeout
@@ -1190,12 +1197,12 @@ class GRobot(object):
         started_at = time.time()
         while not condition():
             if time_for_stop != -1 and time.time() > (started_at + time_for_stop):
-                if self.loaded:
+                if self._loaded:
                     raise OperateTimeout, timeout_message
                 else:
                     # raise LoadingTimeout, timeout_message
                     self.trigger_action('Stop') #QWebPage::Stop
-                    self.loaded = True
+                    self._loaded = True
                     logger.warning("Page loading timeout.Force to stop the page")
                     break
 
@@ -1226,64 +1233,28 @@ class GRobot(object):
             self.inspector.setPage(self.page)
             self.inspector.show()
 
-        selenium_scripts = [
+        scripts = [
             'atoms.js',
             'htmlutils.js',
-            # 'selenium-logging.js',
-            #
-            # 'find_matching_child.js',
-            # 'selenium-api.js',
-            # 'selenium-api-override.js',
-            #
-            # 'selenium-browserbot.js',
-            # 'selenium-browserdetect.js',
-            # 'selenium-commandhandlers.js',
-            # 'xmlextras.js',
         ]
 
-        for script in selenium_scripts:
-            self.evaluate_js_file(os.path.dirname(__file__) + '/../selenium-scripts/' + script)
+        if self.jquery_namespace:
+            scripts.append('jquery-1.9.1.min.js', )
 
-#         self.evaluate(
-#             """
-#             selenium=Selenium.createForWindow(window);
-#             GCrawlerFactory = new CommandHandlerFactory();
-#             GCrawlerFactory.registerAll(selenium);
-#
-#             function do_selenium_command(command,target,value)
-#             {
-#
-#                 var command=new SeleniumCommand(command,target,value, false);
-#                 var handler=GCrawlerFactory.getCommandHandler(command.command);
-#                 if (handler)
-#                 {
-#                     command.target = selenium.preprocessParameter(command.target);
-#                     command.value = selenium.preprocessParameter(command.value);
-#
-#                 try
-#                 {
-#                     handler.execute(selenium, command);
-#                 }catch(e)
-#                 {
-#                     if (e.isSeleniumError)
-#                         e.message;
-#                 }
-#
-#                 }else
-#                 {
-#                     'Do not hava command '+command.command;
-#                 }
-#             }
-#
-# """)
+        for script in scripts:
+            self.evaluate_js_file(os.path.dirname(__file__) + '/../javascripts/' + script)
 
-        self.loaded = True
+        if self.jquery_namespace:
+            self.evaluate(u"%s=jQuery.noConflict();" % self.jquery_namespace)
+
+        self._loaded = True
         # self.cache.clear()
         logger.debug("Page load finished")
 
     def _page_load_started(self):
         logger.debug("Start load page")
-        self.loaded = False
+
+        self._loaded = False
 
     def _unsupported_content(self, reply):
         """Adds an HttpResource object to http_resources with unsupported
